min_and_max_depth

Function min_and_max_depth 

pub fn min_and_max_depth<T>(circuit: &Circuit<T>) -> (T, T)
Calculates minimal and maximal depth of circuit and depth for all circuit wires.

It returns minimal and maximal depth of circuit. A depth is length between circuit input to circuit output.